﻿'' Print Tool Moves in a STEP-NC Process using VB
'' ========================================
''
'' This C# project calls the STEP-NC API using the .NET interface.  It
'' prints all tool moves in a machining program.
''
'' You can find more examples and other documentation at:
''
''      http://www.steptools.com/support/
''

Imports STEPNCLib

Module Module1

    Sub Main()
        Dim finder As finder = New finder
        Dim ctl As Adaptive = New Adaptive

        '' Read a STEP-NC file
        finder.Open238("C:/Program Files (x86)/STEP Tools/STEP-NC Machine/examples/boxy_renton_signed.stpnc")

        '' Start traversing the process within the file.   Uses the active data from finder.
        ctl.StartProject()

        '' The Move event is the only one selected by default
        While ctl.Next() <> Adaptive.CtlEvent.DONE

            Select Case ctl.GetActiveType()

                Case Adaptive.CtlType.MOVE
                    Console.WriteLine("LINEAR MOVE")
                    printend(ctl, ctl.GetMoveEnd())

                Case Adaptive.CtlType.MOVE_ARC
                    Console.WriteLine("ARC MOVE")
                    printarc(ctl, ctl.GetMoveArc())
                    printend(ctl, ctl.GetMoveEnd())

                Case Adaptive.CtlType.MOVE_HELIX
                    Console.WriteLine("HELIX MOVE")
                    printarc(ctl, ctl.GetMoveArc())
                    printend(ctl, ctl.GetMoveEnd())


            End Select
        End While
    End Sub

    Sub printend(ctl As Adaptive, p As UInteger)
        Dim a, b, c As Double
        ctl.GetPosXYZ(a, b, c, p)
        Console.Write("  END: XYZ: {0:0.0####} {1:0.0####} {2:0.0####}", a, b, c)

        ctl.GetPosDirZ(a, b, c, p)
        Console.Write("  ZDIR: {0:0.0####} {1:0.0####} {2:0.0####}", a, b, c)
        Console.WriteLine()
    End Sub

    '' Print arc center, radius, and direction for an arc move
    ''
    Sub printarc(ctl As Adaptive, p As UInteger)
        Dim a, b, c As Double
        ctl.GetPosXYZ(a, b, c, p)
        Console.Write("  END: XYZ: {0:0.0####} {1:0.0####} {2:0.0####}", a, b, c)
        If ctl.GetArcIsCW(p) Then
            Console.Write("  ARC: CW")
        Else
            Console.Write("  ARC: CCW")
        End If

        ctl.GetArcCenter(a, b, c, p)
        Console.Write("  END: XYZ: {0:0.0####} {1:0.0####} {2:0.0####}", a, b, c)

        Console.Write("  RADIUS: {0:0.0####}", ctl.GetArcRadius(p))
        Console.Write("  ANGLE: {0:0.0####}", ctl.GetArcAngle(p))
        Console.WriteLine()
    End Sub

End Module
